% Funció per al càlcul del mòdul (espectre d'amplitud)
% de la Transformada de Fourier X(f) d'un senyal x(t)
% mostrejat a la freqüència fs.
%
% - Paràmetres d'entrada:
%	x:  vector que conté les mostres de x(t)
%	fs: freqüència de mostreig
%
%       No requereix introduir el vector de temps.
%
% - Paràmetres de sortida:
%	modX: vector que conté el mòdul de les mostres de X(f)
%	f:    vector de freqüències corresponents a les mostres de X(f)
%
% Utilitzeu-la amb precaució:
% - El senyal x(t) ha de ser de durada finita;
% - El senyal x(t) ha de ser mostrejat a una freqüència suficientment alta;
% - És recomanable que hi hagi una seqüència de zeros suficientment gran al 
%   davant i/o al darrere dels valors no nuls de x.
%

function [modX,f]=MOD_TF(x,fs)

% Nombre de mostres del senyal x
N=length(x);

% Calcul de la TF
X1=fft(x)/fs;
X=fftshift(X1);
% Càlcul del mòdul
modX=abs(X);

% Freqüència corresponent a cada mostra de X(f)
f=0*X;
f(1:end)=[-ceil((N-1)/2):floor((N-1)/2)]*fs/N;

